@@ -6,6 +6,7 @@ import Test.Tasty
 
 import qualified Test.FLACSpec as FLAC
 import qualified Test.MP3Spec as MP3
+import qualified Test.M4ASpec as M4A
 import qualified Test.WriterSpec as Writer
 import qualified Test.IntegrationSpec as Integration
 
@@ -17,6 +18,7 @@ tests = testGroup "Monatone Parser Tests"
   [ testGroup "Unit Tests"
       [ FLAC.tests
       , MP3.tests
+      , M4A.tests
       , Writer.tests
       ]
   , Integration.tests
